PySkein 0.5 — PySkein v0.5 documentation

### Navigation

- index
- next |
- PySkein v0.5 documentation »

# PySkein 0.5

PySkein is an extension module for Python 3.0 or later, allowing Python scripts to compute hash values with the recently proposed Skein hash algorithm (one of the Second Round Candidates in the NIST SHA-3 Competition). It is based on the optimized version of the Skein reference implementation, written in C by Doug Whiting. This guarantees efficient hashing (373 MB/s for Skein-512-512 called from Python on a 2.8 GHz Opteron).

Note: PySkein 0.5 implements the most recent version of the Skein specification (version 1.2), which defines revised rotation constants. Its hash values are therefore incompatible with those generated by earlier versions of PySkein, which were based on version 1.1 of the specification.

- Computing Skein hashes
  - Examples

- Threefish encryption
  - Examples

- Pseudorandom Number Generator

- Demo Scripts
  - skeinsum
  - threefish

- Download PySkein
  - Previous versions
  - Changes

### Navigation

- index
- next |
- PySkein v0.5 documentation »